@@ -1,3 +1,7 @@
+#[cfg(test)]
+#[path = "../../tests/unit/commands/import_test.rs"]
+mod import_test;
+
 use super::*;
 use std::io::BufReader;
 use vrp_cli::extensions::import::import_problem;
@@ -14,7 +18,7 @@ pub fn get_import_app<'a, 'b>() -> App<'a, 'b> {
             Arg::with_name(FORMAT_ARG_NAME)
                 .help("Specifies input type")
                 .required(true)
-                .possible_values(&["csv", "hre"])
+                .possible_values(&["csv"])
                 .index(1),
         )
         .arg(
