@@ -21,7 +21,7 @@ use vrp_core::solver::{Builder, Telemetry, TelemetryMode};
 use vrp_core::utils::{Environment, Parallelism, Random};
 
 /// An algorithm configuration.
-#[derive(Clone, Deserialize, Debug)]
+#[derive(Clone, Default, Deserialize, Debug)]
 pub struct Config {
     /// Specifies evolution configuration.
     pub evolution: Option<EvolutionConfig>,
@@ -313,6 +313,9 @@ pub enum RecreateMethod {
 #[derive(Clone, Deserialize, Debug)]
 #[serde(tag = "type")]
 pub enum LocalOperatorType {
+    #[serde(rename(deserialize = "swap-star"))]
+    SwapStar { weight: usize },
+
     #[serde(rename(deserialize = "inter-route-best"))]
     InterRouteBest { weight: usize, noise: NoiseConfig },
 
@@ -437,12 +440,6 @@ pub struct NameWeight {
     pub weight: usize,
 }
 
-impl Default for Config {
-    fn default() -> Self {
-        Self { evolution: None, hyper: None, termination: None, processing: None, environment: None, telemetry: None }
-    }
-}
-
 fn configure_from_evolution(
     mut builder: Builder,
     population_config: &Option<EvolutionConfig>,
@@ -612,20 +609,25 @@ fn create_recreate_method(
     method: &RecreateMethod,
     environment: Arc<Environment>,
 ) -> (Arc<dyn Recreate + Send + Sync>, usize) {
+    let random = environment.random.clone();
     match method {
-        RecreateMethod::Cheapest { weight } => (Arc::new(RecreateWithCheapest::default()), *weight),
-        RecreateMethod::Farthest { weight } => (Arc::new(RecreateWithFarthest::default()), *weight),
-        RecreateMethod::SkipBest { weight, start, end } => (Arc::new(RecreateWithSkipBest::new(*start, *end)), *weight),
-        RecreateMethod::Slice { weight } => (Arc::new(RecreateWithSlice::default()), *weight),
+        RecreateMethod::Cheapest { weight } => (Arc::new(RecreateWithCheapest::new(random)), *weight),
+        RecreateMethod::Farthest { weight } => (Arc::new(RecreateWithFarthest::new(random)), *weight),
+        RecreateMethod::SkipBest { weight, start, end } => {
+            (Arc::new(RecreateWithSkipBest::new(*start, *end, random)), *weight)
+        }
+        RecreateMethod::Slice { weight } => (Arc::new(RecreateWithSlice::new(random)), *weight),
         RecreateMethod::Blinks { weight } => {
-            (Arc::new(RecreateWithBlinks::<SingleDimLoad>::new_with_defaults(environment.random.clone())), *weight)
+            (Arc::new(RecreateWithBlinks::<SingleDimLoad>::new_with_defaults(random.clone())), *weight)
+        }
+        RecreateMethod::SkipRandom { weight } => (Arc::new(RecreateWithSkipRandom::new(random)), *weight),
+        RecreateMethod::Gaps { weight, min, max } => (Arc::new(RecreateWithGaps::new(*min, *max, random)), *weight),
+        RecreateMethod::Nearest { weight } => (Arc::new(RecreateWithNearestNeighbor::new(random)), *weight),
+        RecreateMethod::Regret { weight, start, end } => {
+            (Arc::new(RecreateWithRegret::new(*start, *end, random)), *weight)
         }
-        RecreateMethod::SkipRandom { weight } => (Arc::new(RecreateWithSkipRandom::default()), *weight),
-        RecreateMethod::Gaps { weight, min, max } => (Arc::new(RecreateWithGaps::new(*min, *max)), *weight),
-        RecreateMethod::Nearest { weight } => (Arc::new(RecreateWithNearestNeighbor::default()), *weight),
-        RecreateMethod::Regret { weight, start, end } => (Arc::new(RecreateWithRegret::new(*start, *end)), *weight),
         RecreateMethod::Perturbation { weight, probability, min, max } => {
-            (Arc::new(RecreateWithPerturbation::new(*probability, *min, *max, environment.random.clone())), *weight)
+            (Arc::new(RecreateWithPerturbation::new(*probability, *min, *max, random.clone())), *weight)
         }
     }
 }
@@ -649,7 +651,7 @@ fn create_mutation(
             )
         }
         MutationType::LocalSearch { probability, times, operators: inners } => {
-            let operator = create_local_search(times, inners);
+            let operator = create_local_search(times, inners, environment.random.clone());
             (Arc::new(LocalSearch::new(operator)), create_mutation_probability(probability, environment.random.clone()))
         }
         MutationType::Decomposition { routes, repeat, probability } => {
@@ -731,10 +733,15 @@ fn create_ruin_method(
     }
 }
 
-fn create_local_search(times: &MinMaxConfig, inners: &[LocalOperatorType]) -> Arc<dyn LocalOperator + Send + Sync> {
+fn create_local_search(
+    times: &MinMaxConfig,
+    inners: &[LocalOperatorType],
+    random: Arc<dyn Random + Send + Sync>,
+) -> Arc<dyn LocalOperator + Send + Sync> {
     let operators = inners
         .iter()
         .map::<(Arc<dyn LocalOperator + Send + Sync>, usize), _>(|op| match op {
+            LocalOperatorType::SwapStar { weight } => (Arc::new(ExchangeSwapStar::new(random.clone())), *weight),
             LocalOperatorType::InterRouteBest { weight, noise } => {
                 (Arc::new(ExchangeInterRouteBest::new(noise.probability, noise.min, noise.max)), *weight)
             }
