@@ -49,7 +49,7 @@ fn can_solve_solomon_problem_with_generation_limit() {
 
 #[test]
 fn can_require_problem_path() {
-    for format in &["pragmatic", "solomon", "lilim"] {
+    for format in &["pragmatic", "solomon", "lilim", "tsplib"] {
         get_solve_app().get_matches_from_safe(vec!["solve", format]).unwrap_err();
     }
 }
@@ -68,6 +68,12 @@ fn can_specify_experimental_setting() {
     get_solve_app().get_matches_from_safe(args).unwrap();
 }
 
+#[test]
+fn can_specify_round_setting() {
+    let args = vec!["solve", "solomon", SOLOMON_PROBLEM_PATH, "--round"];
+    get_solve_app().get_matches_from_safe(args).unwrap();
+}
+
 #[test]
 fn can_specify_heuristic_setting() {
     for (mode, result) in
